==> cobalt-0.0.1-sources.jar: it/auties/whatsapp/model/message/payment/SendPaymentMessageBuilder.java <==
package it.auties.whatsapp.model.message.payment;

public class SendPaymentMessageBuilder {
    private java.util.Optional<it.auties.whatsapp.model.message.model.MessageContainer> noteMessage;
    private it.auties.whatsapp.model.message.model.ChatMessageKey requestMessageKey;
    private java.util.Optional<it.auties.whatsapp.model.payment.PaymentBackground> background;

    public SendPaymentMessageBuilder() {
        noteMessage = java.util.Optional.empty();
        requestMessageKey = null;
        background = java.util.Optional.empty();
    }

    public SendPaymentMessageBuilder noteMessage(java.util.Optional<it.auties.whatsapp.model.message.model.MessageContainer> noteMessage) {
        this.noteMessage = noteMessage;
        return this;
    }
    public SendPaymentMessageBuilder noteMessage(it.auties.whatsapp.model.message.model.MessageContainer noteMessage) {
        this.noteMessage = java.util.Optional.ofNullable(noteMessage);
        return this;
    }
    public SendPaymentMessageBuilder requestMessageKey(it.auties.whatsapp.model.message.model.ChatMessageKey requestMessageKey) {
        this.requestMessageKey = requestMessageKey;
        return this;
    }
    public SendPaymentMessageBuilder background(java.util.Optional<it.auties.whatsapp.model.payment.PaymentBackground> background) {
        this.background = background;
        return this;
    }
    public SendPaymentMessageBuilder background(it.auties.whatsapp.model.payment.PaymentBackground background) {
        this.background = java.util.Optional.ofNullable(background);
        return this;
    }

    public it.auties.whatsapp.model.message.payment.SendPaymentMessage build() {
        return new it.auties.whatsapp.model.message.payment.SendPaymentMessage(noteMessage, requestMessageKey, background);
    }
}

==> cobalt-0.0.7-sources.jar: it/auties/whatsapp/model/message/payment/SendPaymentMessageBuilder.java <==
package it.auties.whatsapp.model.message.payment;

public class SendPaymentMessageBuilder {
    private java.util.Optional<it.auties.whatsapp.model.message.model.MessageContainer> noteMessage;
    private it.auties.whatsapp.model.message.model.ChatMessageKey requestMessageKey;
    private java.util.Optional<it.auties.whatsapp.model.payment.PaymentBackground> background;

    public SendPaymentMessageBuilder() {
        noteMessage = it.auties.protobuf.builtin.ProtobufOptionalMixin.newOptional();
        requestMessageKey = null;
        background = it.auties.protobuf.builtin.ProtobufOptionalMixin.newOptional();
    }

    public SendPaymentMessageBuilder noteMessage(it.auties.whatsapp.model.message.model.MessageContainer noteMessage) {
        this.noteMessage = it.auties.protobuf.builtin.ProtobufOptionalMixin.ofOptional(noteMessage);
        return this;
    }

    public SendPaymentMessageBuilder requestMessageKey(it.auties.whatsapp.model.message.model.ChatMessageKey requestMessageKey) {
        this.requestMessageKey = requestMessageKey;
        return this;
    }

    public SendPaymentMessageBuilder background(it.auties.whatsapp.model.payment.PaymentBackground background) {
        this.background = it.auties.protobuf.builtin.ProtobufOptionalMixin.ofOptional(background);
        return this;
    }

    public it.auties.whatsapp.model.message.payment.SendPaymentMessage build() {
        return new it.auties.whatsapp.model.message.payment.SendPaymentMessage(noteMessage, requestMessageKey, background);
    }

}
